import 'package:sa_flutter/service.base.dart';

abstract class CrudBase<T> extends ServiceBase<T> {
  final WithTokenGetter tokenGetter;

  CrudBase(
    this.tokenGetter,
    String baseUrl,
    String path,
    String role,
  ) : super(
          baseUrl,
          path,
          role: role,
        );

  getToken() {
    return tokenGetter.getToken();
  }

  Future<T> getOne(String id, {String callRole}) {
    return this.get('$baseUrl/${callRole ?? role}/$path/$id');
  }

  Future<T> getAll({Map params = const {}, String callRole}) {
    return this.get('$baseUrl/${callRole ?? role}/$path');
  }

  Future<T> create(T item, {String callRole}) {
    return this.post('$baseUrl/${callRole ?? role}/$path', item);
  }

  Future<T> edit(String id, T item, {String callRole}) {
    return this.put('$baseUrl/${callRole ?? role}/$path/$id', item);
  }

  Future<T> delete(String id, {String callRole}) {
    return this.delete('$baseUrl/${callRole ?? role}/$path/$id');
  }

  @override
  mapper(data) {
    return data;
  }
}
